## Version 0.0.12

This new version introduces a panel representation of a recorder class and includes a version bump.

### New Features

- Added a panel representation of a recorder class to enhance the user interface and functionality (18ae007) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
